4. Utils — EQcorrscan 0.1.0 documentation

# 4. Utils

Utility functions for integration with other software, and for the analysis of waveforms detected by cross-correlation.

Sfile_util allows for integration with Seisan via event and pick information writing to nordic format s-files. Not all information is currently converted, however pick and origin information are. We now internally store pick and event information in the obspy.core.event classes, which support writing and reading to and from multiple formats, including quakeML and NonLinLoc. The authors recommend using this integration with NonLinLoc for location of events. Because NonLinLoc files can be read in by obspy, and then written out to nordic format files, which can be easily converted to hypoDD files, there are now multiple options for location of events.

- 4.1. clustering
- 4.2. EQcorrscan_plotting
- 4.3. findpeaks
- 4.4. locate
- 4.5. mag_calc
- 4.6. pre_processing
- 4.7. seismo_logs
- 4.8. Sfile_util
- 4.9. stacking
- 4.10. synth_seis